@@ -4,8 +4,6 @@ from os import path
 
 
 FOUNDRY = {
-    'has_javascript': True,
-    'has_ajax': True,
     'sms_gateway_api_key': '',
     'sms_gateway_password': '',
     'layers': ('basic',)
@@ -32,8 +30,8 @@ TEMPLATE_DEBUG = DEBUG
 
 DATABASES = {
     'default': {
-        'ENGINE': 'django.db.backends.sqlite3', # Add 'postgresql_psycopg2', 'postgresql', 'mysql', 'sqlite3' or 'oracle'.
-        'NAME': '/tmp/skeleton.sql', # Or path to database file if using sqlite3.
+        'ENGINE': 'django.contrib.gis.db.backends.spatialite', # Add 'postgresql_psycopg2', 'postgresql', 'mysql', 'sqlite3' or 'oracle'.
+        'NAME': 'skeleton.db', # Or path to database file if using sqlite3.
         'USER': 'skeleton', # Not used with sqlite3.
         'PASSWORD': 'skeleton', # Not used with sqlite3.
         'HOST': '', # Set to empty string for localhost. Not used with sqlite3.
@@ -130,6 +128,7 @@ INSTALLED_APPS = (
     'snippetscream',
     'generate',
     'cal',
+    'jmbo_calendar',
     'jmbo',
     'photologue',
     'captcha',
@@ -157,6 +156,7 @@ INSTALLED_APPS = (
     'analytics',
     'gunicorn',
     'sites_groups',
+    'atlas',        # NEW
     'tastypie',
     'django.contrib.auth',
     'django.contrib.comments',
@@ -165,6 +165,7 @@ INSTALLED_APPS = (
     'django.contrib.sessions',
     'django.contrib.sites',
     'django.contrib.staticfiles',
+    'django.contrib.gis', # NEW
     'django.contrib.admin',
 )
 
@@ -226,9 +227,7 @@ ADMIN_APPS_EXCLUDE = (
 ADMIN_MODELS_EXCLUDE = (
     'Groups',
     'Code banners',
-    'Video embeds',
     'Video files',
-    'Competition preferences',
 )
 
 JMBO_ANALYTICS = {
@@ -236,3 +235,7 @@ JMBO_ANALYTICS = {
 }
 
 PHOTOLOGUE_MAXBLOCK = 2 ** 20
+
+DJANGO_ATLAS = {
+    'google_maps_api_key': 'AIzaSyBvdwGsAn2h6tNI75M5cAcryln7rrTYqkk',
+}
